@@ -11,7 +11,7 @@ Examples
 >>> comparer = con.extract()
 """
 from collections.abc import Mapping, Iterable, Sequence
-from typing import Dict, List, Union
+from typing import Dict, List, Optional, Union
 import warnings
 from inspect import getmembers, isfunction
 import numpy as np
@@ -20,12 +20,74 @@ import matplotlib.pyplot as plt
 from datetime import datetime, timedelta
 from copy import deepcopy
 
-from mikeio import Dataset
+import mikeio
 import fmskill.metrics as mtr
 from .observation import PointObservation, TrackObservation
 from .plot import scatter, taylor_diagram, TaylorPoint
 from .skill import AggregatedSkill
 from .spatial import SpatialSkill
+from .settings import options, register_option, reset_option
+
+register_option(
+    "metrics.list",
+    [mtr.bias, mtr.rmse, mtr.urmse, mtr.mae, mtr.cc, mtr.si, mtr.r2],
+    doc="Default metrics list to be used in skill tables if specific metrics are not provided.",
+)
+
+
+def _interp_time(df: pd.DataFrame, new_time: pd.DatetimeIndex) -> pd.DataFrame:
+    """Interpolate time series to new time index"""
+    new_df = (
+        df.reindex(df.index.union(new_time))
+        .interpolate(method="time", limit_area="inside")
+        .reindex(new_time)
+    )
+    return new_df
+
+
+TimeDeltaTypes = Union[float, int, np.timedelta64, pd.Timedelta, timedelta]
+
+
+def _time_delta_to_pd_timedelta(time_delta: TimeDeltaTypes) -> pd.Timedelta:
+    if isinstance(time_delta, (timedelta, np.timedelta64)):
+        time_delta = pd.Timedelta(time_delta)
+    elif np.isscalar(time_delta):
+        # assume seconds
+        time_delta = pd.Timedelta(time_delta, "s")
+    return time_delta
+
+
+def _remove_model_gaps(
+    df: pd.DataFrame,
+    mod_index: pd.DatetimeIndex,
+    max_gap: TimeDeltaTypes,
+) -> pd.DataFrame:
+    """Remove model gaps longer than max_gap from dataframe"""
+    max_gap = _time_delta_to_pd_timedelta(max_gap)
+    valid_time = _get_valid_query_time(mod_index, df.index, max_gap)
+    return df.loc[valid_time]
+
+
+def _get_valid_query_time(
+    mod_index: pd.DatetimeIndex, obs_index: pd.DatetimeIndex, max_gap: pd.Timedelta
+):
+    # init dataframe of available timesteps and their index
+    df = pd.DataFrame(index=mod_index)
+    df["idx"] = range(len(df))
+
+    # for query times get available left and right index of source times
+    df = _interp_time(df, obs_index).dropna()
+    df["idxa"] = np.floor(df.idx).astype(int)
+    df["idxb"] = np.ceil(df.idx).astype(int)
+
+    # time of left and right source times and time delta
+    df["ta"] = mod_index[df.idxa]
+    df["tb"] = mod_index[df.idxb]
+    df["dt"] = df.tb - df.ta
+
+    # valid query times where time delta is less than max_gap
+    valid_idx = df.dt <= max_gap
+    return valid_idx
 
 
 class BaseComparer:
@@ -90,6 +152,17 @@ class BaseComparer:
             self._construct_all_df()
         return self._all_df
 
+    @property
+    def metrics(self):
+        return options.metrics.list
+
+    @metrics.setter
+    def metrics(self, values) -> None:
+        if values is None:
+            reset_option("metrics.list")
+        else:
+            options.metrics.list = self._parse_metric(values)
+
     def __add__(self, other: "BaseComparer") -> "ComparerCollection":
 
         if not isinstance(other, BaseComparer):
@@ -164,6 +237,7 @@ class BaseComparer:
 
     def __init__(self, observation, modeldata=None):
 
+        # self._metrics = options.metrics.list
         self.obs_name = "Observation"
         self._obs_names: List[str]
         self._mod_names: List[str]
@@ -223,7 +297,7 @@ class BaseComparer:
                 self.add_modeldata(data)
             return
 
-        if isinstance(modeldata, Dataset):
+        if isinstance(modeldata, mikeio.Dataset):
             mod_df = modeldata.to_dataframe()
         elif isinstance(modeldata, pd.DataFrame):
             # TODO: add validation
@@ -240,7 +314,7 @@ class BaseComparer:
         self.mod_data[mod_name] = mod_df
         self._mod_names = list(self.mod_data.keys())
 
-        time = mod_df.index.round(freq="ms")  # 0.001s accuracy
+        time = mod_df.index.round(freq="100us")  # 0.0001s accuracy
         mod_df.index = pd.DatetimeIndex(time, freq="infer")
 
         if mod_df.index[0] < self._mod_start:
@@ -333,7 +407,7 @@ class BaseComparer:
 
     def _parse_metric(self, metric, return_list=False):
         if metric is None:
-            return [mtr.bias, mtr.rmse, mtr.urmse, mtr.mae, mtr.cc, mtr.si, mtr.r2]
+            metric = self.metrics
 
         if isinstance(metric, str):
             valid_metrics = [
@@ -380,7 +454,7 @@ class BaseComparer:
             e.g.: 'freq:M' = monthly; 'freq:D' daily
             by default ["model","observation"]
         metrics : list, optional
-            list of fmskill.metrics, by default [bias, rmse, urmse, mae, cc, si, r2]
+            list of fmskill.metrics, by default fmskill.options.metrics.list
         model : (str, int, List[str], List[int]), optional
             name or ids of models to be compared, by default all
         observation : (str, int, List[str], List[int])), optional
@@ -564,7 +638,7 @@ class BaseComparer:
             e.g.: 'freq:M' = monthly; 'freq:D' daily
             by default ["model","observation"]
         metrics : list, optional
-            list of fmskill.metrics, by default [bias, rmse, urmse, mae, cc, si, r2]
+            list of fmskill.metrics, by default fmskill.options.metrics.list
         n_min : int, optional
             minimum number of observations in a grid cell;
             cells with fewer observations get a score of `np.nan`
@@ -820,8 +894,8 @@ class BaseComparer:
         bins: Union[int, float, List[int], List[float]] = 20,
         quantiles: Union[int, List[float]] = None,
         show_points: Union[bool, int, float] = None,
-        show_hist: bool = True,
-        show_density: bool = False,
+        show_hist: bool = None,
+        show_density: bool = None,
         backend: str = "matplotlib",
         figsize: List[float] = (8, 8),
         xlim: List[float] = None,
@@ -839,6 +913,7 @@ class BaseComparer:
         df: pd.DataFrame = None,
         binsize: float = None,
         nbins: int = None,
+        skill_table: Union[str, List[str], bool] = None,
         **kwargs,
     ):
         """Scatter plot showing compared data: observation vs modelled
@@ -861,9 +936,10 @@ class BaseComparer:
             float: fraction of points to show on plot from 0 to 1. eg 0.5 shows 50% of the points.
             int: if 'n' (int) given, then 'n' points will be displayed, randomly selected
         show_hist : bool, optional
-            show the data density as a a 2d histogram, by default True
-        density: bool, optional
-            show the data density as a colormap of the scatter, by default False.
+            show the data density as a a 2d histogram, by default None
+        show_density: bool, optional
+            show the data density as a colormap of the scatter, by default None. If both `show_density` and `show_hist`
+        are None, then `show_density` is used by default.
             for binning the data, the previous kword `bins=Float` is used
         backend : str, optional
             use "plotly" (interactive) or "matplotlib" backend, by default "matplotlib"
@@ -900,12 +976,16 @@ class BaseComparer:
             by default None
         df : pd.dataframe, optional
             show user-provided data instead of the comparers own data, by default None
+        skill_table : str, List[str], bool, optional
+            list of fmskill.metrics or boolean, if True then by default fmskill.options.metrics.list.
+            This kword adds a box at the right of the scatter plot,
+            by default False
         kwargs
 
         Examples
         ------
         >>> comparer.scatter()
-        >>> comparer.scatter(binsize=0.2, backend='plotly')
+        >>> comparer.scatter(bins=0.2, backend='plotly')
         >>> comparer.scatter(show_points=False, title='no points')
         >>> comparer.scatter(xlabel='all observations', ylabel='my model')
         >>> comparer.scatter(model='HKZN_v2', figsize=(10, 10))
@@ -948,7 +1028,35 @@ class BaseComparer:
         if title is None:
             title = f"{self.mod_names[mod_id]} vs {self.name}"
 
-        scatter(
+        if skill_table != None:
+            # Calculate Skill if it was requested to add as table on the right of plot
+            if skill_table == True:
+                if isinstance(self, PointComparer) or (
+                    isinstance(self, ComparerCollection) and self.n_observations == 1
+                ):
+                    skill_df = self.skill(
+                        df=df, model=model, observation=observation, variable=variable
+                    )
+                else:
+                    skill_df = self.mean_skill(
+                        df=df, model=model, observation=observation, variable=variable
+                    )
+
+            # Check for units
+            try:
+                units = unit_text.split("[")[1].split("]")[0]
+            except:
+                #     Dimensionless
+                units = ""
+            if skill_table == False:
+                skill_df = None
+                units = None
+        else:
+            # skill_table is None
+            skill_df = None
+            units = None
+
+        ax=scatter(
             x=x,
             y=y,
             bins=bins,
@@ -964,10 +1072,13 @@ class BaseComparer:
             title=title,
             xlabel=xlabel,
             ylabel=ylabel,
+            skill_df=skill_df,
+            units=units,
             binsize=binsize,
             nbins=nbins,
             **kwargs,
         )
+        return ax
 
     def taylor(
         self,
@@ -1085,39 +1196,32 @@ class BaseComparer:
 
 
 class SingleObsComparer(BaseComparer):
+    def __init__(self, observation, model):
+        super().__init__(observation, model)
+
     def __copy__(self):
-        # cls = self.__class__
-        # cp = cls.__new__(cls)
-        # cp.__init__(self.observation, self.mod_df)
-        # return cp
         return deepcopy(self)
 
     def copy(self):
         return self.__copy__()
 
-    def _model2obs_interp(self, obs, mod_df):
+    def _model2obs_interp(self, obs, mod_df: pd.DataFrame, max_model_gap: Optional[TimeDeltaTypes]):
         """interpolate model to measurement time"""
-        df = self._interp_df(mod_df, obs.time)
-        # mod_ds.interp_time(obs.time).to_dataframe()
+        df = _interp_time(mod_df.dropna(), obs.time)
         df[self.obs_name] = obs.values
-        return df
 
-    @staticmethod
-    def _interp_df(df, new_time):
-        assert df.index.is_unique
-        assert new_time.is_unique
-        new_df = (
-            df.reindex(df.index.union(new_time))
-            .interpolate(method="time", limit_area="inside")
-            .reindex(new_time)
-        )
-        return new_df
+        if max_model_gap is not None:
+            df = _remove_model_gaps(df, mod_df.dropna().index, max_model_gap)
+
+        return df
 
     def skill(
         self,
         by: Union[str, List[str]] = None,
         metrics: list = None,
         model: Union[str, int, List[str], List[int]] = None,
+        observation=None,  # Only used to have a compatible interface with other skill mehod TODO refactor to a new sel() method
+        variable=None,  # Only used to have a compatible interface with other skill mehod TODO refactor to a new sel() method
         start: Union[str, datetime] = None,
         end: Union[str, datetime] = None,
         area: List[float] = None,
@@ -1133,7 +1237,7 @@ class SingleObsComparer(BaseComparer):
             e.g.: 'freq:M' = monthly; 'freq:D' daily
             by default ["model"]
         metrics : list, optional
-            list of fmskill.metrics, by default [bias, rmse, urmse, mae, cc, si, r2]
+            list of fmskill.metrics, by default fmskill.options.metrics.list
         model : (str, int, List[str], List[int]), optional
             name or ids of models to be compared, by default all
         freq : string, optional
@@ -1439,7 +1543,9 @@ class SingleObsComparer(BaseComparer):
         plt.title(title)
         plt.xlabel(f"Residuals of {self._obs_unit_text}")
 
-    def hist(self, model=None, bins=100, title=None, alpha=0.5, **kwargs):
+    def hist(
+        self, *, model=None, bins=100, title=None, density=True, alpha=0.5, **kwargs
+    ):
         """Plot histogram of model data and observations.
 
         Wraps pandas.DataFrame hist() method.
@@ -1452,6 +1558,8 @@ class SingleObsComparer(BaseComparer):
             number of bins, by default 100
         title : str, optional
             plot title, default: [model name] vs [observation name]
+        density: bool, optional
+            If True, draw and return a probability density
         alpha : float, optional
             alpha transparency fraction, by default 0.5
         kwargs : other keyword arguments to df.hist()
@@ -1459,6 +1567,12 @@ class SingleObsComparer(BaseComparer):
         Returns
         -------
         matplotlib axes
+
+        See also
+        --------
+        pandas.Series.hist
+        matplotlib.axes.Axes.hist
+
         """
         mod_id = self._get_mod_id(model)
         mod_name = self.mod_names[mod_id]
@@ -1466,6 +1580,7 @@ class SingleObsComparer(BaseComparer):
         title = f"{mod_name} vs {self.name}" if title is None else title
 
         kwargs["alpha"] = alpha
+        kwargs["density"] = density
         ax = self.df[mod_name].hist(bins=bins, color=self._mod_colors[mod_id], **kwargs)
         self.df[self.obs_name].hist(
             bins=bins, color=self.observation.color, ax=ax, **kwargs
@@ -1473,6 +1588,11 @@ class SingleObsComparer(BaseComparer):
         ax.legend([mod_name, self.obs_name])
         plt.title(title)
         plt.xlabel(f"{self._obs_unit_text}")
+        if density:
+            plt.ylabel("density")
+        else:
+            plt.ylabel("count")
+
         return ax
 
 
@@ -1489,7 +1609,9 @@ class PointComparer(SingleObsComparer):
     >>> comparer['Klagshamn']
     """
 
-    def __init__(self, observation, modeldata):
+    def __init__(
+        self, observation, modeldata, max_model_gap: Optional[TimeDeltaTypes] = None
+    ):
         super().__init__(observation, modeldata)
         assert isinstance(observation, PointObservation)
         mod_start = self._mod_start - timedelta(seconds=1)  # avoid rounding err
@@ -1498,8 +1620,12 @@ class PointComparer(SingleObsComparer):
 
         if not isinstance(modeldata, list):
             modeldata = [modeldata]
+        # max_model_gap = self._parse_max_gap(modeldata, max_model_gap)
+
         for j, data in enumerate(modeldata):
-            df = self._model2obs_interp(self.observation, data).iloc[:, ::-1]
+            df = self._model2obs_interp(self.observation, data, max_model_gap).iloc[
+                :, ::-1
+            ]
             if j == 0:
                 self.df = df
             else:
@@ -1612,15 +1738,17 @@ class TrackComparer(SingleObsComparer):
     def y(self):
         return self.df.iloc[:, 1]
 
-    def __init__(self, observation, modeldata):
+    def __init__(self, observation, modeldata, max_model_gap: float = None):
         super().__init__(observation, modeldata)
         assert isinstance(observation, TrackObservation)
         self.observation.df = self.observation.df[self._mod_start : self._mod_end]
 
         if not isinstance(modeldata, list):
             modeldata = [modeldata]
+        # max_model_gap = self._parse_max_gap(modeldata, max_model_gap)
+
         for j, data in enumerate(modeldata):
-            df = self._model2obs_interp(self.observation, data)
+            df = self._model2obs_interp(self.observation, data, max_model_gap)
             # rename first columns to x, y
             df.columns = ["x", "y", *list(df.columns)[2:]]
             if (len(df) > 0) and (len(df) == len(self.observation.df)):
@@ -1754,17 +1882,24 @@ class ComparerCollection(Mapping, Sequence, BaseComparer):
         self._all_df = res.sort_index()
         self._all_df.index.name = "datetime"
 
-    def __init__(self):
-
+    def __init__(self, comparers=None):
+        # super().__init__(observation=None, modeldata=None)  # Not possible since init signature is different compared to BaseComparer
+        # self._metrics = options.metrics.list
         self._all_df = None
         self._start = datetime(2900, 1, 1)
         self._end = datetime(1, 1, 1)
-        self.comparers = {}
         self._mod_names = []
         self._obs_names = []
         self._var_names = []
         self._itemInfos = []
 
+        self.comparers = {}
+
+        if comparers is not None:
+            for c in comparers:
+                if c is not None:
+                    self._add_comparer(c)
+
     def __repr__(self):
         out = []
         out.append(f"<{type(self).__name__}>")
@@ -1774,9 +1909,8 @@ class ComparerCollection(Mapping, Sequence, BaseComparer):
 
     def __getitem__(self, x):
         if isinstance(x, slice):
-            cc = ComparerCollection()
-            for xi in range(*x.indices(len(self))):
-                cc.add_comparer(self[xi])
+            cmps = [self[xi] for xi in range(*x.indices(len(self)))]
+            cc = ComparerCollection(cmps)
             return cc
 
         if isinstance(x, int):
@@ -1853,6 +1987,7 @@ class ComparerCollection(Mapping, Sequence, BaseComparer):
         area: List[float] = None,
         df: pd.DataFrame = None,
         title: str = None,
+        density=True,
         alpha: float = 0.5,
         **kwargs,
     ):
@@ -1882,6 +2017,8 @@ class ComparerCollection(Mapping, Sequence, BaseComparer):
             user-provided data instead of the comparers own data, by default None
         title : str, optional
             plot title, default: observation name
+        density: bool, optional
+            If True, draw and return a probability density
         alpha : float, optional
             alpha transparency fraction, by default 0.5
         kwargs : other keyword arguments to df.hist()
@@ -1889,6 +2026,11 @@ class ComparerCollection(Mapping, Sequence, BaseComparer):
         Returns
         -------
         matplotlib axes
+
+        See also
+        --------
+        pandas.Series.hist
+        matplotlib.axes.Axes.hist
         """
         mod_id = self._get_mod_id(model)
         mod_name = self.mod_names[mod_id]
@@ -1910,11 +2052,18 @@ class ComparerCollection(Mapping, Sequence, BaseComparer):
         title = f"{mod_name} vs Observations" if title is None else title
 
         kwargs["alpha"] = alpha
+        kwargs["density"] = density
         ax = df.mod_val.hist(bins=bins, color=self[0]._mod_colors[mod_id], **kwargs)
         df.obs_val.hist(bins=bins, color=self[0].observation.color, ax=ax, **kwargs)
         ax.legend([mod_name, "observations"])
         plt.title(title)
         plt.xlabel(f"{self._obs_unit_text}")
+
+        if density:
+            plt.ylabel("density")
+        else:
+            plt.ylabel("count")
+
         return ax
 
     def mean_skill(
@@ -1948,7 +2097,7 @@ class ComparerCollection(Mapping, Sequence, BaseComparer):
             dictionary of observations with special weigths, others will be set to 1.0
             by default None (i.e. observations weight attribute if assigned else "equal")
         metrics : list, optional
-            list of fmskill.metrics, by default [bias, rmse, urmse, mae, cc, si, r2]
+            list of fmskill.metrics, by default fmskill.options.metrics.list
         model : (str, int, List[str], List[int]), optional
             name or ids of models to be compared, by default all
         observation : (str, int, List[str], List[int])), optional
@@ -2063,7 +2212,7 @@ class ComparerCollection(Mapping, Sequence, BaseComparer):
         Parameters
         ----------
         metrics : list, optional
-            list of fmskill.metrics, by default [bias, rmse, urmse, mae, cc, si, r2]
+            list of fmskill.metrics, by default fmskill.options.metrics.list
         model : (str, int, List[str], List[int]), optional
             name or ids of models to be compared, by default all
         observation : (str, int, List[str], List[int])), optional
