@@ -1,4 +1,4 @@
 from .factory import ModelResult
-from .dfs import DfsModelResult, DfsModelResultItem
+from .dfs import DfsModelResult, DfsModelResultItem, DataArrayModelResultItem
 from .pandas import DataFramePointModelResult, DataFramePointModelResultItem
 from .xarray import XArrayModelResult, XArrayModelResultItem
