@@ -4,13 +4,33 @@ import numpy as np
 import pandas as pd
 import warnings
 
-from mikeio import Dfs0, Dfsu, Dataset, eum
+import mikeio
 from ..observation import Observation, PointObservation, TrackObservation
 from ..comparison import PointComparer, TrackComparer, ComparerCollection, BaseComparer
 from ..utils import make_unique_index
 from .abstract import ModelResultInterface, MultiItemModelResult
 
 
+def _validate_item_eum(mod_item: mikeio.ItemInfo, obs: Observation) -> bool:
+    """Check that observation and model item eum match"""
+    ok = True
+    if obs.itemInfo.type == mikeio.EUMType.Undefined:
+        warnings.warn(f"{obs.name}: Cannot validate as type is Undefined.")
+        return ok
+
+    if mod_item.type != obs.itemInfo.type:
+        ok = False
+        warnings.warn(
+            f"{obs.name}: Item type should match. Model item: {mod_item.type.display_name}, obs item: {obs.itemInfo.type.display_name}"
+        )
+    if mod_item.unit != obs.itemInfo.unit:
+        ok = False
+        warnings.warn(
+            f"{obs.name}: Unit should match. Model unit: {mod_item.unit.display_name}, obs unit: {obs.itemInfo.unit.display_name}"
+        )
+    return ok
+
+
 class _DfsBase:
     @property
     def start_time(self) -> pd.Timestamp:
@@ -26,11 +46,11 @@ class _DfsBase:
 
     @property
     def is_dfsu(self):
-        return isinstance(self.dfs, Dfsu)
+        return isinstance(self.dfs, mikeio.dfsu._Dfsu)
 
     @property
     def is_dfs0(self):
-        return isinstance(self.dfs, Dfs0)
+        return isinstance(self.dfs, mikeio.Dfs0)
 
     def _in_domain(self, x, y) -> bool:
         ok = True
@@ -46,7 +66,7 @@ class _DfsBase:
                 return 0
             else:
                 return None
-        if isinstance(item, eum.ItemInfo):
+        if isinstance(item, mikeio.ItemInfo):
             item = item.name
         if isinstance(item, int):
             if item < 0:  # Handle negative indices
@@ -112,16 +132,16 @@ class _DfsBase:
 
         return ds_model.to_dataframe().dropna()
 
-    def _extract_point_dfsu(self, x, y, item) -> Dataset:
+    def _extract_point_dfsu(self, x, y, item) -> mikeio.Dataset:
         xy = np.atleast_2d([x, y])
-        elemids, _ = self.dfs.get_2d_interpolant(xy, n_nearest=1)
+        elemids = self.dfs.geometry.find_index(coords=xy)
         ds_model = self.dfs.read(elements=elemids, items=[item])
-        ds_model.items[0].name = self.name
+        ds_model.rename({ds_model.items[0].name: self.name}, inplace=True)
         return ds_model
 
-    def _extract_point_dfs0(self, item) -> Dataset:
+    def _extract_point_dfs0(self, item) -> mikeio.Dataset:
         ds_model = self.dfs.read(items=[item])
-        ds_model.items[0].name = self.name
+        ds_model.rename({ds_model.items[0].name: self.name}, inplace=True)
         return ds_model
 
     def _extract_track(self, observation: TrackObservation, item=None) -> pd.DataFrame:
@@ -133,14 +153,16 @@ class _DfsBase:
             df = ds_model.to_dataframe().dropna()
         elif self.is_dfs0:
             ds_model = self.dfs.read(items=[0, 1, item])
-            ds_model.items[-1].name = self.name
+            ds_model.rename({ds_model.items[-1].name: self.name}, inplace=True)
             df = ds_model.to_dataframe().dropna()
-            df.index = make_unique_index(df.index, offset_in_seconds=0.01)
+            df.index = make_unique_index(df.index, offset_duplicates=0.001)
         return df
 
-    def _extract_track_dfsu(self, observation: TrackObservation, item) -> Dataset:
+    def _extract_track_dfsu(
+        self, observation: TrackObservation, item
+    ) -> mikeio.Dataset:
         ds_model = self.dfs.extract_track(track=observation.df, items=[item])
-        ds_model.items[-1].name = self.name
+        ds_model.rename({ds_model.items[-1].name: self.name}, inplace=True)
         return ds_model
 
     @staticmethod
@@ -164,6 +186,91 @@ class _DfsBase:
         raise NotImplementedError("Deprecated! Use Connector instead.")
 
 
+class DataArrayModelResultItem(ModelResultInterface):
+    @property
+    def start_time(self) -> pd.Timestamp:
+        return self._da.time[0]
+
+    @property
+    def end_time(self) -> pd.Timestamp:
+        return self._da.time[-1]
+
+    @property
+    def item_name(self):
+        return self._da.name
+
+    def __init__(self, da: mikeio.DataArray, name=None):
+        self._da = da
+        if name is None:
+            self.name = self._da.name
+        else:
+            self.name = name
+
+    def __repr__(self):
+        txt = [f"<DataArrayModelResultItem> '{self.name}'"]
+        txt.append(f"- Item: {self.itemInfo}")
+        return "\n".join(txt)
+
+    @property
+    def itemInfo(self):
+        return self._da.item
+
+    def _extract_point(self, observation: PointObservation) -> pd.DataFrame:
+
+        dap = self._da.sel(x=observation.x, y=observation.y)
+        dap.name = self.name
+        # ds_model.rename({ds_model.items[0].name: self.name}, inplace=True)
+
+        # Why is there no .to_dataframe() on DataArray?
+        return mikeio.Dataset(dap).to_dataframe().dropna()
+
+    def _extract_track(self, observation: TrackObservation) -> pd.DataFrame:
+        ds = self._da.extract_track(observation.df)
+        ds.rename({ds.items[-1].name: self.name}, inplace=True)
+        return ds.to_dataframe().dropna()
+
+    def extract_observation(
+        self, observation: Union[PointObservation, TrackObservation], validate=True
+    ) -> BaseComparer:
+        """Extract ModelResult at observation for comparison
+
+        Parameters
+        ----------
+        observation : <PointObservation> or <TrackObservation>
+            points and times at which modelresult should be extracted
+        validate: bool, optional
+            Validate if observation is inside domain and that eum type
+            and units match; Default: True
+
+        Returns
+        -------
+        <fmskill.BaseComparer>
+            A comparer object for further analysis or plotting
+        """
+
+        if validate:
+            # ok = self._validate_observation(observation)
+            # if ok:
+            ok = _validate_item_eum(self.itemInfo, observation)
+            if not ok:
+                raise ValueError("Could not extract observation")
+
+        if isinstance(observation, PointObservation):
+            df_model = self._extract_point(observation)
+            comparer = PointComparer(observation, df_model)
+        elif isinstance(observation, TrackObservation):
+            df_model = self._extract_track(observation)
+            comparer = TrackComparer(observation, df_model)
+        else:
+            raise ValueError("Only point and track observation are supported!")
+
+        if len(comparer.df) == 0:
+            warnings.warn(f"No overlapping data in found for obs '{observation.name}'!")
+            comparer = None
+
+        return comparer
+
+
 class DfsModelResultItem(_DfsBase, ModelResultInterface):
     @property
     def item_name(self):
@@ -184,7 +291,7 @@ class DfsModelResultItem(_DfsBase, ModelResultInterface):
         return "\n".join(txt)
 
     def extract_observation(
-        self, observation: Union[PointObservation, TrackObservation], validate=True
+        self, observation: Union[PointObservation, TrackObservation], validate=True, **kwargs
     ) -> BaseComparer:
         """Extract ModelResult at observation for comparison
 
@@ -209,16 +316,16 @@ class DfsModelResultItem(_DfsBase, ModelResultInterface):
         if validate:
             ok = self._validate_observation(observation)
             if ok:
-                ok = self._validate_item_eum(observation)
+                ok = _validate_item_eum(self.itemInfo, observation)
             if not ok:
                 raise ValueError("Could not extract observation")
 
         if isinstance(observation, PointObservation):
             df_model = self._extract_point(observation, item)
-            comparer = PointComparer(observation, df_model)
+            comparer = PointComparer(observation, df_model, **kwargs)
         elif isinstance(observation, TrackObservation):
             df_model = self._extract_track(observation, item)
-            comparer = TrackComparer(observation, df_model)
+            comparer = TrackComparer(observation, df_model, **kwargs)
         else:
             raise ValueError("Only point and track observation are supported!")
 
@@ -228,27 +335,6 @@ class DfsModelResultItem(_DfsBase, ModelResultInterface):
 
         return comparer
 
-    def _validate_item_eum(self, observation: Observation) -> bool:
-        """Check that observation and model item eum match"""
-        ok = True
-        obs_item = observation.itemInfo
-        if obs_item.type == eum.EUMType.Undefined:
-            warnings.warn(f"{observation.name}: Cannot validate as type is Undefined.")
-            return ok
-
-        item = self.itemInfo
-        if item.type != obs_item.type:
-            ok = False
-            warnings.warn(
-                f"{observation.name}: Item type should match. Model item: {item.type.display_name}, obs item: {obs_item.type.display_name}"
-            )
-        if item.unit != obs_item.unit:
-            ok = False
-            warnings.warn(
-                f"{observation.name}: Unit should match. Model unit: {item.unit.display_name}, obs unit: {obs_item.unit.display_name}"
-            )
-        return ok
-
 
 class DfsModelResult(_DfsBase, MultiItemModelResult):
     @property
@@ -264,11 +350,11 @@ class DfsModelResult(_DfsBase, MultiItemModelResult):
         self._filename = filename
         ext = os.path.splitext(filename)[-1]
         if ext == ".dfsu":
-            self.dfs = Dfsu(filename)
+            self.dfs = mikeio.open(filename)
         # elif ext == '.dfs2':
-        #    self.dfs = Dfs2(filename)
+        #    self.dfs = mikeio.open(filename)
         elif ext == ".dfs0":
-            self.dfs = Dfs0(filename)
+            self.dfs = mikeio.open(filename)
         else:
             raise ValueError(f"Filename extension {ext} not supported (dfsu, dfs0)")
 
@@ -279,7 +365,7 @@ class DfsModelResult(_DfsBase, MultiItemModelResult):
         self._mr_items = {}
         for it in self.dfs.items:
             self._mr_items[it.name] = DfsModelResultItem(
-                self.dfs, it, self._filename, self.name
+                self.dfs, it, self._filename, self.name,
             )
 
         if item is not None:
@@ -300,7 +386,7 @@ class DfsModelResult(_DfsBase, MultiItemModelResult):
 #     def _infer_model_item(
 #         self,
 #         observation: Observation,
-#         mod_items: List[eum.ItemInfo] = None,
+#         mod_items: List[mikeio.ItemInfo] = None,
 #     ) -> int:
 #         """Attempt to infer model item by matching observation eum with model eum"""
 #         if mod_items is None:
