@@ -1,9 +1,9 @@
 import os
+from typing import Dict
 import numpy as np
 import pandas as pd
 import warnings
 
-from mikeio import eum
 from ..observation import Observation, PointObservation, TrackObservation
 from ..comparison import PointComparer, TrackComparer
 from .abstract import ModelResultInterface, MultiItemModelResult, _parse_itemInfo
@@ -23,7 +23,7 @@ class _XarrayBase:
         return self._filename
 
     @staticmethod
-    def _get_new_coord_names(coords):
+    def _get_new_coord_names(coords) -> Dict[str, str]:
         new_names = {}
         for coord in coords:
             c = coord.lower()
@@ -31,7 +31,7 @@ class _XarrayBase:
                 new_names[coord] = "x"
             elif ("y" not in new_names) and (("lat" in c) or ("north" in c)):
                 new_names[coord] = "y"
-            elif ("time" not in new_names) and (("time" in c) or ("date" in c)):
+            elif ("time" not in new_names) and "date" in c:
                 new_names[coord] = "time"
         return new_names
 
@@ -60,7 +60,7 @@ class _XarrayBase:
                 return item_names[0]
             else:
                 return None
-        # if isinstance(item, eum.ItemInfo):
+        # if isinstance(item, mikeio.ItemInfo):
         #     item = item.name
         if isinstance(item, int):
             if item < 0:  # Handle negative indices
@@ -157,7 +157,7 @@ class XArrayModelResultItem(_XarrayBase, ModelResultInterface):
         self.name = name
         self._filename = filename
 
-    def extract_observation(self, observation: PointObservation) -> PointComparer:
+    def extract_observation(self, observation: PointObservation, **kwargs) -> PointComparer:
         """Compare this ModelResult with an observation
 
         Parameters
@@ -176,10 +176,10 @@ class XArrayModelResultItem(_XarrayBase, ModelResultInterface):
 
         if isinstance(observation, PointObservation):
             df_model = self._extract_point(observation, item)
-            comparer = PointComparer(observation, df_model)
+            comparer = PointComparer(observation, df_model, **kwargs)
         elif isinstance(observation, TrackObservation):
             df_model = self._extract_track(observation, item)
-            comparer = TrackComparer(observation, df_model)
+            comparer = TrackComparer(observation, df_model, **kwargs)
         else:
             raise ValueError("Only point and track observation are supported!")
 
@@ -239,11 +239,9 @@ class XArrayModelResult(_XarrayBase, MultiItemModelResult):
         self._mr_items = {}
         for it in self.item_names:
             self._mr_items[it] = XArrayModelResultItem(
-                self.ds, self.name, item=it, itemInfo=itemInfo, filename=self._filename
+                self.ds, self.name, item=it, itemInfo=itemInfo, filename=self._filename,
             )
 
     def _rename_coords(self, ds):
         new_names = self._get_new_coord_names(ds.coords)
-        if len(new_names) > 0:
-            ds = ds.rename(new_names)
-        return ds
+        return ds.rename(new_names)
