@@ -6,11 +6,54 @@ from scipy import interpolate
 
 import matplotlib.pyplot as plt
 
-from mikeio import Dfsu
+import mikeio
 
 from .observation import Observation, PointObservation, TrackObservation
 from .metrics import _linear_regression
 from .plot_taylor import TaylorDiagram
+import fmskill.settings as settings
+from .settings import options, register_option
+
+
+register_option("plot.scatter.points.size", 20, validator=settings.is_positive)
+register_option("plot.scatter.points.alpha", 0.5, validator=settings.is_between_0_and_1)
+register_option("plot.scatter.points.label", "", validator=settings.is_str)
+register_option("plot.scatter.quantiles.marker", "X", validator=settings.is_str)
+register_option(
+    "plot.scatter.quantiles.markersize", 3.5, validator=settings.is_positive
+)
+register_option(
+    "plot.scatter.quantiles.color",
+    "darkturquoise",
+    validator=settings.is_tuple_list_or_str,
+)
+register_option("plot.scatter.quantiles.label", "Q-Q", validator=settings.is_str)
+register_option(
+    "plot.scatter.quantiles.markeredgecolor",
+    (0, 0, 0, 0.4),
+    validator=settings.is_tuple_list_or_str,
+)
+register_option(
+    "plot.scatter.quantiles.markeredgewidth", 0.5, validator=settings.is_positive
+)
+register_option("plot.scatter.quantiles.kwargs", {}, settings.is_dict)
+register_option("plot.scatter.oneone_line.label", "1:1", validator=settings.is_str)
+register_option(
+    "plot.scatter.oneone_line.color", "blue", validator=settings.is_tuple_list_or_str
+)
+register_option("plot.scatter.legend.kwargs", {}, settings.is_dict)
+register_option("plot.scatter.reg_line.kwargs", {"color": "r"}, settings.is_dict)
+register_option(
+    "plot.scatter.legend.bbox",
+    {
+        "facecolor": "blue",
+        "edgecolor": "k",
+        "boxstyle": "round",
+        "alpha": 0.05,
+    },
+    settings.is_dict,
+)
+# register_option("plot.scatter.table.show", False, validator=settings.is_bool)
 
 
 def scatter(
@@ -20,8 +63,8 @@ def scatter(
     bins: Union[int, float, List[int], List[float]] = 20,
     quantiles: Union[int, List[float]] = None,
     show_points: Union[bool, int, float] = None,
-    show_hist: bool = True,
-    show_density: bool = False,
+    show_hist: bool = None,
+    show_density: bool = None,
     backend: str = "matplotlib",
     figsize: List[float] = (8, 8),
     xlim: List[float] = None,
@@ -30,6 +73,8 @@ def scatter(
     title: str = "",
     xlabel: str = "",
     ylabel: str = "",
+    skill_df: object = None,
+    units: str = "",
     binsize: float = None,
     nbins: int = None,
     **kwargs,
@@ -58,9 +103,10 @@ def scatter(
         float: fraction of points to show on plot from 0 to 1. eg 0.5 shows 50% of the points.
         int: if 'n' (int) given, then 'n' points will be displayed, randomly selected.
     show_hist : bool, optional
-        show the data density as a 2d histogram, by default True
+        show the data density as a 2d histogram, by default None
     show_density: bool, optional
-        show the data density as a colormap of the scatter, by default False.
+        show the data density as a colormap of the scatter, by default None. If both `show_density` and `show_hist`
+        are None, then `show_density` is used by default.
         for binning the data, the previous kword `bins=Float` is used
     backend : str, optional
         use "plotly" (interactive) or "matplotlib" backend, by default "matplotlib"
@@ -81,8 +127,15 @@ def scatter(
         x-label text on plot, by default None
     ylabel : str, optional
         y-label text on plot, by default None
+    skill_df : dataframe, optional
+        dataframe with skill (stats) results to be added to plot, by default None
+    units : str, optional
+        user default units to override default units, eg 'metre', by default None
     kwargs
     """
+    if show_hist == None and show_density == None:
+        # Default: points density
+        show_density = True
 
     if (binsize is not None) or (nbins is not None):
         warnings.warn(
@@ -101,11 +154,11 @@ def scatter(
     y_sample = y
 
     if show_points is None:
-        # If nothing given, and more than 10k points, 10k sample will be shown
-        if len(x) < 1e4:
+        # If nothing given, and more than 50k points, 50k sample will be shown
+        if len(x) < 5e4:
             show_points = True
         else:
-            show_points = 10000
+            show_points = 50000
     if type(show_points) == float:
         if show_points < 0 or show_points > 1:
             raise ValueError(" `show_points` fraction must be in [0,1]")
@@ -174,13 +227,23 @@ def scatter(
         xq = np.quantile(x, q=quantiles)
         yq = np.quantile(y, q=quantiles)
 
+    if show_hist:
+        # if histogram is wanted (explicit non-default flag) then density is off
+        if show_density == True:
+            raise TypeError(
+                "if `show_hist=True` then `show_density` must be either `False` or `None`"
+            )
+
     if show_density:
         if not ((type(bins) == float) or (type(bins) == int)):
             raise TypeError(
                 "if `show_density=True` then bins must be either float or int"
             )
         # if point density is wanted, then 2D histogram is not shown
-        show_hist = False
+        if show_hist == True:
+            raise TypeError(
+                "if `show_density=True` then `show_hist` must be either `False` or `None`"
+            )
         # calculate density data
         z = _scatter_density(x_sample, y_sample, binsize=binsize)
         idx = z.argsort()
@@ -199,13 +262,13 @@ def scatter(
     reglabel = f"Fit: y={slope:.2f}x{sign}{intercept:.2f}"
 
     if backend == "matplotlib":
-
-        plt.figure(figsize=figsize)
+        _,ax=plt.subplots(figsize=figsize)
+        #plt.figure(figsize=figsize)
         plt.plot(
             [xlim[0], xlim[1]],
             [xlim[0], xlim[1]],
-            label="1:1",
-            c="blue",
+            label=options.plot.scatter.oneone_line.label,
+            c=options.plot.scatter.oneone_line.color,
             zorder=3,
         )
         if show_points:
@@ -217,33 +280,36 @@ def scatter(
                 x_sample,
                 y_sample,
                 c=c,
-                s=20,
-                alpha=0.5,
+                s=options.plot.scatter.points.size,
+                alpha=options.plot.scatter.points.alpha,
                 marker=".",
-                label=None,
+                label=options.plot.scatter.points.label,
                 zorder=1,
                 **kwargs,
             )
         plt.plot(
             xq,
             yq,
-            "X",
-            label="Q-Q",
-            c="darkturquoise",
-            markeredgecolor=(0, 0, 0, 0.6),
+            options.plot.scatter.quantiles.marker,
+            label=options.plot.scatter.quantiles.label,
+            c=options.plot.scatter.quantiles.color,
             zorder=4,
+            markeredgecolor=options.plot.scatter.quantiles.markeredgecolor,
+            markeredgewidth=options.plot.scatter.quantiles.markeredgewidth,
+            markersize=options.plot.scatter.quantiles.markersize,
+            **settings.get_option("plot.scatter.quantiles.kwargs"),
         )
         plt.plot(
             x,
             intercept + slope * x,
-            "r",
+            **settings.get_option("plot.scatter.reg_line.kwargs"),
             label=reglabel,
             zorder=2,
         )
         if show_hist:
             plt.hist2d(x, y, bins=nbins_hist, cmin=0.01, zorder=0.5, **kwargs)
 
-        plt.legend()
+        plt.legend(**settings.get_option("plot.scatter.legend.kwargs"))
         plt.xlabel(xlabel)
         plt.ylabel(ylabel)
         plt.axis("square")
@@ -253,10 +319,18 @@ def scatter(
         plt.grid(
             which="both", axis="both", linestyle=":", linewidth="0.2", color="grey"
         )
-        if show_hist or show_density:
+        max_cbar = None
+        if show_hist or (show_density and show_points):
             cbar = plt.colorbar(fraction=0.046, pad=0.04)
+            ticks = cbar.ax.get_yticks()
+            max_cbar = ticks[-1]
             cbar.set_label("# points")
+
         plt.title(title)
+        # Add skill table
+        if skill_df != None:
+            _plot_summary_table(skill_df, units, max_cbar=max_cbar)
+        return ax
 
     elif backend == "plotly":  # pragma: no cover
         import plotly.graph_objects as go
@@ -312,10 +386,10 @@ def scatter(
             go.Scatter(
                 x=xq,
                 y=yq,
-                name="Q-Q",
+                name=options.plot.scatter.quantiles.label,
                 mode="markers",
                 marker_symbol="x",
-                marker_color="darkturquoise",
+                marker_color=options.plot.scatter.quantiles.color,
                 marker_line_color="midnightblue",
                 marker_line_width=0.6,
             )
@@ -344,14 +418,17 @@ def scatter(
 
 
 def plot_observation_positions(
-    dfs: Dfsu, observations: List[Observation], figsize: Tuple = None, title=None
+    geometry: mikeio.spatial.FM_geometry.GeometryFM,
+    observations: List[Observation],
+    figsize: Tuple = None,
+    title=None,
 ):
     """Plot observation points on a map showing the model domain
 
     Parameters
     ----------
-    dfs: Dfsu
-        model object
+    geometry: mikeio.GeometryFM
+        A MIKE IO geometry object
     observations: list
         Observation collection
     figsize : (float, float), optional
@@ -360,9 +437,9 @@ def plot_observation_positions(
         plot title, default empty
     """
 
-    xn = dfs.node_coordinates[:, 0]
+    xn = geometry.node_coordinates[:, 0]
     offset_x = 0.02 * (max(xn) - min(xn))
-    ax = dfs.plot(plot_type="outline_only", figsize=figsize)
+    ax = geometry.plot(plot_type="outline_only", figsize=figsize)
     for obs in observations:
         if isinstance(obs, PointObservation):
             ax.scatter(x=obs.x, y=obs.y, marker="x")
@@ -478,3 +555,52 @@ def _scatter_density(x, y, binsize: float = 0.1, method: str = "linear"):
     Z_grid[(Z_grid < 0)] = 0
 
     return Z_grid
+
+
+def _plot_summary_table(skill_df, units, max_cbar):
+    stats_with_units = ["bias", "rmse", "urmse", "mae"]
+    max_str_len = skill_df.columns.str.len().max()
+    lines = []
+
+    for col in skill_df.columns:
+        if col == "model" or col == "variable":
+            continue
+        if col in stats_with_units:
+            # if statistic has dimensions, then add units
+            item_unit = units
+        else:
+            # else, add empty space (for fomatting)
+            item_unit = " "
+        if col == "n":
+            # Number of samples, integer, else, 2 decimals
+            decimals = f".{0}f"
+        else:
+            decimals = f".{2}f"
+        lines.append(
+            f"{(col.ljust(max_str_len)).upper()} = {np.round(skill_df[col].values[0],2): {decimals}} {item_unit}"
+        )
+
+    text_ = "\n".join(lines)
+
+    if max_cbar == None:
+        x = 0.93
+    elif max_cbar < 1e3:
+        x = 0.99
+    elif max_cbar < 1e4:
+        x = 1.01
+    elif max_cbar < 1e5:
+        x = 1.03
+    elif max_cbar < 1e6:
+        x = 1.05
+    else:
+        # When more than 1e6 samples, matplotlib changes to scientific notation
+        x = 0.97
+
+    plt.gcf().text(
+        x,
+        0.6,
+        text_,
+        bbox=settings.get_option("plot.scatter.legend.bbox"),
+        fontsize=12,
+        family="monospace",
+    )
