@@ -4,7 +4,7 @@ import pytest
 import xarray as xr
 import pandas as pd
 
-from mikeio import eum
+import mikeio
 
 import fmskill
 from fmskill.model import ModelResult
@@ -59,7 +59,7 @@ def test_XArrayModelResult_from_nc(modelresult):
     assert mr.item_names == ["mwd", "mwp", "mp2", "pp1d", "swh"]
     assert mr.start_time == datetime(2017, 10, 27, 0, 0, 0)
     assert mr.end_time == datetime(2017, 10, 29, 18, 0, 0)
-    assert mr[0].itemInfo == eum.ItemInfo(eum.EUMType.Undefined)
+    assert mr[0].itemInfo == mikeio.ItemInfo(mikeio.EUMType.Undefined)
 
 
 def test_XArrayModelResult_from_ds(ERA5_DutchCoast_nc):
@@ -70,7 +70,7 @@ def test_XArrayModelResult_from_ds(ERA5_DutchCoast_nc):
     assert isinstance(mr.ds, xr.Dataset)
     assert mr.item_names == ["mwd", "mwp", "mp2", "pp1d", "swh"]
     assert not mr.filename
-    assert mr[0].itemInfo == eum.ItemInfo(eum.EUMType.Undefined)
+    assert mr[0].itemInfo == mikeio.ItemInfo(mikeio.EUMType.Undefined)
 
 
 def test_XArrayModelResult_from_da(ERA5_DutchCoast_nc):
@@ -114,15 +114,15 @@ def test_XArrayModelResultItem(ERA5_DutchCoast_nc):
 
 def test_XArrayModelResultItem_itemInfo(ERA5_DutchCoast_nc):
     mri1 = ModelResult(ERA5_DutchCoast_nc, item="pp1d")
-    assert mri1.itemInfo == eum.ItemInfo(eum.EUMType.Undefined)
+    assert mri1.itemInfo == mikeio.ItemInfo(mikeio.EUMType.Undefined)
 
-    itemInfo = eum.EUMType.Wave_period
+    itemInfo = mikeio.EUMType.Wave_period
     mri3 = ModelResult(ERA5_DutchCoast_nc, item="pp1d", itemInfo=itemInfo)
-    mri3.itemInfo == eum.ItemInfo(eum.EUMType.Wave_period)
+    mri3.itemInfo == mikeio.ItemInfo(mikeio.EUMType.Wave_period)
 
-    itemInfo = eum.ItemInfo("Peak period", eum.EUMType.Wave_period)
+    itemInfo = mikeio.ItemInfo("Peak period", mikeio.EUMType.Wave_period)
     mri3 = ModelResult(ERA5_DutchCoast_nc, item="pp1d", itemInfo=itemInfo)
-    mri3.itemInfo == eum.ItemInfo("Peak period", eum.EUMType.Wave_period)
+    mri3.itemInfo == mikeio.ItemInfo("Peak period", mikeio.EUMType.Wave_period)
 
 
 def test_XArrayModelResult_getitem(modelresult):
